@@ -4,14 +4,9 @@
 
 #include "ReaderFilter.h"
 
-#include "ReaderConfiguration.h"
-#include "ReaderManagerPlugIn.h"
+#include "ReaderConfigurationInfo.h"
 
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
-	#include <QMutableListIterator>
-#else
-	#include <QMutableVectorIterator>
-#endif
+#include <QMutableListIterator>
 
 using namespace governikus;
 
