@@ -93,10 +93,4 @@ struct CertificateDescription
 
 DECLARE_ASN1_FUNCTIONS(CertificateDescription)
 DECLARE_ASN1_OBJECT(CertificateDescription)
-
-#if OPENSSL_VERSION_NUMBER < 0x10100000L || defined(LIBRESSL_VERSION_NUMBER)
-	#define sk_ASN1_OCTET_STRING_num(data) data->stack.num
-	#define sk_ASN1_OCTET_STRING_value(data, i) SKM_sk_value(ASN1_OCTET_STRING, data, i)
-#endif
-
 } // namespace governikus
