@@ -18,8 +18,6 @@
 #include <QString>
 #include <QVector>
 
-class test_HistoryModel;
-
 namespace governikus
 {
 
@@ -28,7 +26,6 @@ class ProviderConfiguration
 {
 	Q_OBJECT
 	friend class Env;
-	friend class ::test_HistoryModel;
 
 	private:
 		const QSharedPointer<UpdatableFile> mUpdatableFile;
