@@ -16,19 +16,11 @@
 
 namespace governikus
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-	#define defineQHash(enumName)\
+#define defineQHash(enumName)\
 	inline size_t qHash(enumName pKey, size_t pSeed)\
 	{\
 		return ::qHash(static_cast<std::underlying_type_t<enumName>>(pKey), pSeed);\
 	}
-#else
-	#define defineQHash(enumName)\
-	inline uint qHash(enumName pKey, uint pSeed)\
-	{\
-		return ::qHash(static_cast<std::underlying_type_t<enumName>>(pKey), pSeed);\
-	}
-#endif
 
 #define defineEnumOperators(enumName)\
 	inline QDebug operator<<(QDebug pDbg, enumName pType)\
