@@ -26,7 +26,6 @@ class FailureCode
 		{
 			User_Cancelled,
 			Card_Removed,
-			Processing_Send_Status_Failed,
 			Parse_TcToken_Invalid_Url,
 			Parse_TcToken_Missing_Url,
 			Get_TcToken_Invalid_Url,
@@ -34,6 +33,9 @@ class FailureCode
 			Get_TcToken_Invalid_Certificate_Key_Length,
 			Get_TcToken_Invalid_Ephemeral_Key_Length,
 			Get_TcToken_Invalid_Server_Reply,
+			Get_TcToken_ServiceUnavailable,
+			Get_TcToken_Server_Error,
+			Get_TcToken_Client_Error,
 			Get_TcToken_Empty_Data,
 			Get_TcToken_Invalid_Data,
 			Get_TcToken_Network_Error,
@@ -53,7 +55,6 @@ class FailureCode
 			Connect_Card_Connection_Failed,
 			Connect_Card_Eid_Inactive,
 			Prepace_Pace_Smart_Eid_Invalidated,
-			Establish_Pace_Channel_No_Active_Pin,
 			Establish_Pace_Channel_Basic_Reader_No_Pin,
 			Establish_Pace_Channel_Puk_Inoperative,
 			Establish_Pace_Channel_User_Cancelled,
@@ -66,6 +67,7 @@ class FailureCode
 			Generic_Send_Receive_Network_Error,
 			Generic_Send_Receive_Tls_Error,
 			Generic_Send_Receive_Server_Error,
+			Generic_Send_Receive_Service_Unavailable,
 			Generic_Send_Receive_Client_Error,
 			Generic_Send_Receive_Paos_Unknown,
 			Generic_Send_Receive_Paos_Unexpected,
@@ -78,6 +80,8 @@ class FailureCode
 			Check_Refresh_Address_Fatal_Tls_Error_Before_Reply,
 			Check_Refresh_Address_Invalid_Ephemeral_Key_Length,
 			Check_Refresh_Address_Service_Unavailable,
+			Check_Refresh_Address_Server_Error,
+			Check_Refresh_Address_Client_Error,
 			Check_Refresh_Address_Service_Timeout,
 			Check_Refresh_Address_Proxy_Error,
 			Check_Refresh_Address_Fatal_Tls_Error_After_Reply,
@@ -89,12 +93,14 @@ class FailureCode
 			Check_Refresh_Address_Fetch_Certificate_Error,
 			Check_Refresh_Address_Unsupported_Certificate,
 			Check_Refresh_Address_Hash_Missing_In_Certificate,
-			Redirect_Browser_Send_Error_Page_Failed,
-			Redirect_Browser_Send_Redirect_Failed,
+			Browser_Send_Failed,
 			Generic_Provider_Communication_Network_Error,
 			Generic_Provider_Communication_Invalid_Ephemeral_Key_Length,
 			Generic_Provider_Communication_Certificate_Error,
 			Generic_Provider_Communication_Tls_Error,
+			Generic_Provider_Communication_ServiceUnavailable,
+			Generic_Provider_Communication_Server_Error,
+			Generic_Provider_Communication_Client_Error,
 			Get_SelfAuthData_Invalid_Or_Empty,
 			Change_Pin_No_SetEidPinCommand_Response,
 			Change_Pin_Input_Timeout,
@@ -109,31 +115,54 @@ class FailureCode
 			Establish_Pace_Ifd_Unknown,
 			Enter_Pace_Password_Ifd_User_Cancelled,
 			Enter_New_Pace_Pin_Ifd_User_Cancelled,
+			Check_Status_Unavailable,
+			Install_Smart_User_Cancelled,
+			Delete_Smart_User_Cancelled,
+			Delete_Personalization_User_Cancelled,
+			Update_Support_Info_User_Cancelled,
+			Install_Smart_Service_Response_Fail,
+			Install_Smart_Service_Response_Unsupported,
+			Install_Smart_Service_Response_Overload,
+			Install_Smart_Service_Response_Maintenance,
+			Install_Smart_Service_Response_Nfc_Disabled,
+			Install_Smart_Service_Response_Integrity_Check_Failed,
+			Install_Smart_Service_Response_Not_Authenticated,
+			Install_Smart_Service_Response_Network_Connection_Error,
+			Update_Support_Info_Call_Failed,
+			Update_Support_Info_Service_Response_Fail,
+			Update_Support_Info_Service_Response_Unsupported,
+			Update_Support_Info_Service_Response_Overload,
+			Update_Support_Info_Service_Response_Maintenance,
+			Update_Support_Info_Service_Response_Nfc_Disabled,
+			Update_Support_Info_Service_Response_Integrity_Check_Failed,
+			Update_Support_Info_Service_Response_Not_Authenticated,
+			Update_Support_Info_Service_Response_Network_Connection_Error,
+			Delete_Smart_Service_Response_Fail,
+			Delete_Smart_Service_Response_Unsupported,
+			Delete_Smart_Service_Response_Overload,
+			Delete_Smart_Service_Response_Maintenance,
+			Delete_Smart_Service_Response_Nfc_Disabled,
+			Delete_Smart_Service_Response_Integrity_Check_Failed,
+			Delete_Smart_Service_Response_Not_Authenticated,
+			Delete_Smart_Service_Response_Network_Connection_Error,
+			Delete_Personalization_Failed,
+			Check_Applet_Internal_Error,
+			Get_Session_Id_Invalid,
+			Smart_ServiceInformation_Query_Failed,
+			Get_Challenge_Invalid,
+			Initialize_Personalization_Failed,
+			Smart_PrePersonalization_Wrong_Status,
+			Smart_PrePersonalization_Incomplete_Information,
 			Transmit_Personalization_Size_Mismatch,
 			Start_Paos_Response_Personalization_Empty,
 			Start_Paos_Response_Personalization_Invalid,
-			Prepare_Applet_User_Cancelled,
-			Prepare_Applet_Status_Call_Failed,
-			Prepare_Applet_Installation_Loop,
-			Prepare_Applet_Installation_Failed,
-			Prepare_Applet_Unavailable,
-			Prepare_Applet_Delete_Personalization_Failed,
-			Prepare_Applet_UpdateInfo_Call_Failed,
-			Prepare_Applet_Delete_Smart_Failed,
+			Finalize_Personalization_Failed,
 			Insert_Card_No_SmartReader,
 			Insert_Card_Multiple_SmartReader,
 			Insert_Card_Unknown_Eid_Type,
-			Insert_Card_HW_Keystore,
 			Insert_Card_Invalid_SmartReader,
 			Insert_Card_Missing_Card,
-			Initialize_Personalization_Failed,
-			Get_Session_Id_Invalid,
-			Get_Challenge_Invalid,
-			Finalize_Personalization_Failed,
-			Change_Smart_Pin_Failed,
-			Check_Status_Unavailable,
-			Check_Applet_Error,
-			Check_Applet_Unavailable
+			Change_Smart_Pin_Failed
 		};
 		Q_ENUM(Reason)
 
