@@ -5,6 +5,7 @@
 #include "WebSocketChannel.h"
 
 #include "RemoteServiceSettings.h"
+#include "SecureStorage.h"
 
 #include <QLoggingCategory>
 #include <QThread>
@@ -94,6 +95,13 @@ void WebSocketChannel::close()
 }
 
 
+bool WebSocketChannel::isPairingConnection() const
+{
+	const auto& pairingCiphers = Env::getSingleton<SecureStorage>()->getTlsConfigRemoteIfd(SecureStorage::TlsSuite::PSK).getCiphers();
+	return pairingCiphers.contains(mConnection->sslConfiguration().sessionCipher());
+}
+
+
 const QString& WebSocketChannel::getId() const
 {
 	return mId;
