@@ -11,8 +11,11 @@
 #include "IfdList.h"
 #include "IfdReaderManagerPlugIn.h"
 
+#include <QStringList>
 #include <QTimer>
 
+class test_RemoteIfdReaderManagerPlugIn;
+
 namespace governikus
 {
 
@@ -23,14 +26,18 @@ class RemoteIfdReaderManagerPlugIn
 	Q_PLUGIN_METADATA(IID "governikus.ReaderManagerPlugIn" FILE "metadata.json")
 	Q_INTERFACES(governikus::ReaderManagerPlugIn)
 
+	friend class ::test_RemoteIfdReaderManagerPlugIn;
+
 	private:
 		QTimer mScanTimer;
 		bool mConnectToPairedReaders;
-		bool mConnectionCheckInProgress;
+		QStringList mConnectionAttempts;
 
 	private Q_SLOTS:
 		void connectToPairedReaders();
 		void continueConnectToPairedReaders(const QVector<QSharedPointer<IfdListEntry>>& pRemoteDevices);
+		void onDeviceVanished(const QSharedPointer<IfdListEntry>& pEntry);
+		void onEstablishConnectionDone(const QSharedPointer<IfdListEntry>& pEntry, const GlobalStatus& pStatus);
 
 	public:
 		RemoteIfdReaderManagerPlugIn();
