@@ -1,5 +1,5 @@
-/*!
- * \copyright Copyright (c) 2018-2023 Governikus GmbH & Co. KG, Germany
+/**
+ * Copyright (c) 2018-2023 Governikus GmbH & Co. KG, Germany
  */
 
 #include "PortFile.h"
@@ -52,6 +52,12 @@ void PortFile::remove()
 }
 
 
+const QFile& PortFile::getFile() const
+{
+	return mPortFile;
+}
+
+
 QFileInfoList PortFile::getAllPortFiles()
 {
 	QDir tmpPath = QDir::temp();
