@@ -11,7 +11,6 @@ AppSettings::AppSettings()
 	: QObject()
 	, mGeneralSettings()
 	, mPreVerificationSettings()
-	, mHistorySettings()
 	, mRemoteReaderSettings()
 {
 }
@@ -29,12 +28,6 @@ PreVerificationSettings& AppSettings::getPreVerificationSettings()
 }
 
 
-HistorySettings& AppSettings::getHistorySettings()
-{
-	return mHistorySettings;
-}
-
-
 RemoteServiceSettings& AppSettings::getRemoteServiceSettings()
 {
 	return mRemoteReaderSettings;
