@@ -28,8 +28,8 @@ class UIPlugInFunctional
 	private Q_SLOTS:
 		void onApplicationStarted() override;
 		void doShutdown() override;
-		void onWorkflowStarted(QSharedPointer<WorkflowContext> pContext) override;
-		void onWorkflowFinished(QSharedPointer<WorkflowContext> pContext) override;
+		void onWorkflowStarted(const QSharedPointer<WorkflowRequest>& pRequest) override;
+		void onWorkflowFinished(const QSharedPointer<WorkflowRequest>& pRequest) override;
 		void onJsonMessage(const QByteArray& pMessage);
 
 	public Q_SLOTS:
