@@ -20,10 +20,10 @@ class MsgHandlerWorkflows
 	protected:
 		void handleWorkflowProperties(const QJsonObject& pObj, MsgContext& pContext);
 
-		void initMessages(const QJsonObject& pUi);
-		void initDeveloperMode(const QJsonValue& pValue);
-		void initHandleInterrupt(const QJsonValue& pValue, const MsgContext& pContext);
-		void initProgressStatus(const QJsonValue& pValue, MsgContext& pContext);
+		void initMessages(const QJsonObject& pUi) const;
+		void initDeveloperMode(const QJsonValue& pValue) const;
+		void initHandleInterrupt(const QJsonValue& pValue, const MsgContext& pContext) const;
+		void initProgressStatus(const QJsonValue& pValue, MsgContext& pContext) const;
 		void setError(const QLatin1String pError);
 
 		using MsgHandler::MsgHandler;
