@@ -16,6 +16,9 @@
 #endif
 
 
+class test_UIPlugInQml;
+
+
 namespace governikus
 {
 
@@ -24,10 +27,13 @@ class PersonalizationModel
 {
 	Q_OBJECT
 	friend class Env;
+	friend class ::test_UIPlugInQml;
 
 	Q_PROPERTY(QString blockingCode READ getBlockingCode NOTIFY fireBlockingCodeChanged)
 	Q_PROPERTY(int remainingAttempts READ getRemainingAttempts NOTIFY fireRemainingAttemptsChanged)
 	Q_PROPERTY(QString restrictionDate READ getRestrictionDate NOTIFY fireRestrictionDateChanged)
+	Q_PROPERTY(QString blockingPeriodMessage READ getBlockingPeriodMessage NOTIFY fireRestrictionDateChanged)
+	Q_PROPERTY(bool applet READ isApplet NOTIFY fireIsAppletChanged)
 
 	private:
 		PersonalizationModel();
@@ -42,20 +48,23 @@ class PersonalizationModel
 #endif
 
 	public:
-		Q_INVOKABLE void startWorkflow();
+		Q_INVOKABLE void startWorkflow() const;
 		[[nodiscard]] QString getBlockingCode() const;
 		[[nodiscard]] int getRemainingAttempts() const;
 		[[nodiscard]] QString getRestrictionDate() const;
+		[[nodiscard]] QString getBlockingPeriodMessage() const;
+		[[nodiscard]] bool isApplet() const;
 		[[nodiscard]] QVector<ReaderManagerPlugInType> getSupportedReaderPlugInTypes() const override;
 
 	public Q_SLOTS:
 		void onTranslationChanged();
 
 	Q_SIGNALS:
-		void fireStartWorkflow(const QSharedPointer<WorkflowRequest>& pRequest);
+		void fireStartWorkflow(const QSharedPointer<WorkflowRequest>& pRequest) const;
 		void fireBlockingCodeChanged();
 		void fireRemainingAttemptsChanged();
 		void fireRestrictionDateChanged();
+		void fireIsAppletChanged();
 };
 
 } // namespace governikus
