@@ -5,7 +5,6 @@
 #include "ReaderModel.h"
 
 #include "Env.h"
-#include "HelpAction.h"
 #include "LanguageLoader.h"
 #include "ReaderConfiguration.h"
 #include "ReaderManager.h"
@@ -20,27 +19,23 @@
 using namespace governikus;
 
 
-ReaderModel::ReaderModel(QObject* pParent)
-	: QAbstractListModel(pParent)
-	, mKnownDrivers()
-	, mConnectedReaders()
-	, mConnectedReadersUpdateTime()
-	, mSortedModel()
+QString ReaderModel::getLastUpdatedInformation() const
 {
-	const ReaderManager* const readerManager = Env::getSingleton<ReaderManager>();
-	connect(readerManager, &ReaderManager::fireReaderAdded, this, &ReaderModel::onUpdateContent);
-	connect(readerManager, &ReaderManager::fireReaderRemoved, this, &ReaderModel::onUpdateContent);
-	connect(readerManager, &ReaderManager::fireStatusChanged, this, &ReaderModel::onUpdateContent);
-	connect(Env::getSingleton<ReaderConfiguration>(), &ReaderConfiguration::fireUpdated, this, &ReaderModel::onUpdateContent);
-#if !defined(Q_OS_ANDROID) && !defined(Q_OS_IOS)
-	connect(Env::getSingleton<ReaderDetector>(), &ReaderDetector::fireReaderChangeDetected, this, &ReaderModel::onUpdateContent);
-#endif
+	if (!mConnectedReadersUpdateTime.isValid())
+	{
+		return QString();
+	}
 
-	mSortedModel.setSourceModel(this);
-	QQmlEngine::setObjectOwnership(&mSortedModel, QQmlEngine::CppOwnership);
-	connect(this, &ReaderModel::fireModelChanged, &mSortedModel, &SortedReaderModel::onDataChanged);
+	//: LABEL ALL_PLATFORMS Time format according to https://doc.qt.io/qt/qtime.html#toString
+	const auto& updateTime = LanguageLoader::getInstance().getUsedLocale().toString(mConnectedReadersUpdateTime, tr("hh:mm:ss AP"));
+	//: LABEL ALL_PLATFORMS
+	return tr("The list of card readers was last updated at %1.").arg(updateTime);
+}
 
-	onUpdateContent();
+
+SortedReaderModel* ReaderModel::getSortedModel()
+{
+	return &mSortedModel;
 }
 
 
@@ -93,6 +88,79 @@ bool ReaderModel::indexIsValid(const QModelIndex& pIndex) const
 }
 
 
+QUrl ReaderModel::getReaderImageUrl(const QModelIndex& pIndex) const
+{
+	return mConnectedReaders.at(pIndex.row()).getIcon()->lookupUrl();
+}
+
+
+QString ReaderModel::getHTMLDescription(const QModelIndex& pIndex) const
+{
+	if (!indexIsValid(pIndex))
+	{
+		return QString();
+	}
+
+	if (mConnectedReaders.isEmpty())
+	{
+		return QString();
+	}
+
+	const auto& readerSupported = isSupportedReader(pIndex);
+	const auto& readerInstalled = isInstalledReader(pIndex);
+
+	if (readerSupported)
+	{
+		if (readerInstalled)
+		{
+			//: LABEL ALL_PLATFORMS
+			return tr("Driver installed");
+		}
+
+		if (!Env::getSingleton<ReaderManager>()->getPlugInInfo(ReaderManagerPlugInType::PCSC).isScanRunning())
+		{
+			//: LABEL ALL_PLATFORMS
+			return tr("The smartcard service of your system is not reachable.");
+		}
+
+		//: LABEL ALL_PLATFORMS
+		const auto& driverInfo = tr("No driver installed");
+		//: INFO ALL_PLATFORMS The driver for card reader needs to be installed, the download link is provided in the message.
+		const auto& driverDownloadInfo = tr("Please download and install the driver you can find at: %1").
+				arg(QStringLiteral("<a href=\"%1\">%1</a>").arg(mConnectedReaders.at(pIndex.row()).getUrl()));
+
+		return driverInfo + QStringLiteral("<br>") + driverDownloadInfo;
+	}
+
+	//: INFO ALL_PLATFORMS
+	return tr("This card reader is not officially supported and may not work as expected.");
+}
+
+
+bool ReaderModel::isSupportedReader(const QModelIndex& pIndex) const
+{
+	if (!indexIsValid(pIndex))
+	{
+		return false;
+	}
+
+	const auto& readerSettingsInfo = mConnectedReaders.at(pIndex.row());
+	return readerSettingsInfo.isKnownReader();
+}
+
+
+bool ReaderModel::isInstalledReader(const QModelIndex& pIndex) const
+{
+	if (!indexIsValid(pIndex))
+	{
+		return false;
+	}
+
+	const auto& readerSettingsInfo = mConnectedReaders.at(pIndex.row());
+	return mKnownDrivers.contains(readerSettingsInfo);
+}
+
+
 void ReaderModel::onUpdateContent()
 {
 	beginResetModel();
@@ -106,15 +174,33 @@ void ReaderModel::onUpdateContent()
 }
 
 
-void ReaderModel::onTranslationChanged()
+ReaderModel::ReaderModel(QObject* pParent)
+	: QAbstractListModel(pParent)
+	, mKnownDrivers()
+	, mConnectedReaders()
+	, mConnectedReadersUpdateTime()
+	, mSortedModel()
 {
+	const ReaderManager* const readerManager = Env::getSingleton<ReaderManager>();
+	connect(readerManager, &ReaderManager::fireReaderAdded, this, &ReaderModel::onUpdateContent);
+	connect(readerManager, &ReaderManager::fireReaderRemoved, this, &ReaderModel::onUpdateContent);
+	connect(readerManager, &ReaderManager::fireStatusChanged, this, &ReaderModel::onUpdateContent);
+	connect(Env::getSingleton<ReaderConfiguration>(), &ReaderConfiguration::fireUpdated, this, &ReaderModel::onUpdateContent);
+#if !defined(Q_OS_ANDROID) && !defined(Q_OS_IOS)
+	connect(Env::getSingleton<ReaderDetector>(), &ReaderDetector::fireReaderChangeDetected, this, &ReaderModel::onUpdateContent);
+#endif
+
+	mSortedModel.setSourceModel(this);
+	QQmlEngine::setObjectOwnership(&mSortedModel, QQmlEngine::CppOwnership);
+	connect(this, &ReaderModel::fireModelChanged, &mSortedModel, &SortedReaderModel::onDataChanged);
+
 	onUpdateContent();
 }
 
 
 int ReaderModel::rowCount(const QModelIndex&) const
 {
-	return mConnectedReaders.size();
+	return static_cast<int>(mConnectedReaders.size());
 }
 
 
@@ -164,105 +250,7 @@ QHash<int, QByteArray> ReaderModel::roleNames() const
 }
 
 
-QUrl ReaderModel::getReaderImageUrl(const QModelIndex& pIndex) const
+void ReaderModel::onTranslationChanged()
 {
-	return mConnectedReaders.at(pIndex.row()).getIcon()->lookupUrl();
-}
-
-
-QString ReaderModel::getHTMLDescription(const QModelIndex& pIndex) const
-{
-	if (!indexIsValid(pIndex))
-	{
-		return QString();
-	}
-
-	if (mConnectedReaders.isEmpty())
-	{
-		return QString();
-	}
-
-	const auto& readerSupported = isSupportedReader(pIndex);
-	const auto& readerInstalled = isInstalledReader(pIndex);
-
-	if (readerSupported)
-	{
-		if (readerInstalled)
-		{
-			//: LABEL ALL_PLATFORMS
-			return tr("Driver installed");
-		}
-
-		if (!Env::getSingleton<ReaderManager>()->isScanRunning(ReaderManagerPlugInType::PCSC))
-		{
-			//: LABEL ALL_PLATFORMS
-			return tr("The smartcard service of your system is not reachable.");
-		}
-
-		//: LABEL ALL_PLATFORMS
-		const auto& driverInfo = tr("No driver installed");
-		//: INFO ALL_PLATFORMS The driver for card reader needs to be installed, the download link is provided in the message.
-		const auto& driverDownloadInfo = tr("Please download and install the driver you can find at: %1").
-				arg(QStringLiteral("<a href=\"%1\">%1</a>").arg(mConnectedReaders.at(pIndex.row()).getUrl()));
-
-		return driverInfo + QStringLiteral("<br>") + driverDownloadInfo;
-	}
-
-	//: INFO ALL_PLATFORMS
-	return tr("This card reader is not officially supported and may not work as expected.");
-}
-
-
-QString ReaderModel::getEmptyListDescriptionString() const
-{
-	const QString& onlineHelpSection = QStringLiteral("settingsPcscReader");
-	const QString& url = HelpAction::getOnlineUrl(onlineHelpSection);
-	//: Is embedded in a sentence.
-	const QString& hyperlink = QStringLiteral("<a href=\"%1\">%2</a>").arg(url, tr("online help"));
-	//: INFO ALL_PLATFORMS No card reader was found, the message contains a link to the installation section of the manual.
-	return tr("No connected card reader found. See %1 for installation of card readers.").arg(hyperlink);
-}
-
-
-bool ReaderModel::isSupportedReader(const QModelIndex& pIndex) const
-{
-	if (!indexIsValid(pIndex))
-	{
-		return false;
-	}
-
-	const auto& readerSettingsInfo = mConnectedReaders.at(pIndex.row());
-	return readerSettingsInfo.isKnownReader();
-}
-
-
-bool ReaderModel::isInstalledReader(const QModelIndex& pIndex) const
-{
-	if (!indexIsValid(pIndex))
-	{
-		return false;
-	}
-
-	const auto& readerSettingsInfo = mConnectedReaders.at(pIndex.row());
-	return mKnownDrivers.contains(readerSettingsInfo);
-}
-
-
-QString ReaderModel::getLastUpdatedInformation() const
-{
-	if (!mConnectedReadersUpdateTime.isValid())
-	{
-		return QString();
-	}
-
-	//: LABEL ALL_PLATFORMS Time format according to https://doc.qt.io/qt/qtime.html#toString
-	const auto& updateTime = LanguageLoader::getInstance().getUsedLocale().toString(mConnectedReadersUpdateTime, tr("hh:mm:ss AP"));
-	//: LABEL ALL_PLATFORMS
-	return tr("The list of card readers was last updated at %1.").arg(updateTime);
-}
-
-
-SortedReaderModel* ReaderModel::getSortedModel()
-{
-	return &mSortedModel;
+	onUpdateContent();
 }
