@@ -41,8 +41,8 @@ class UIPlugInWebSocket
 
 	private Q_SLOTS:
 		void doShutdown() override;
-		void onWorkflowStarted(QSharedPointer<WorkflowContext> pContext) override;
-		void onWorkflowFinished(QSharedPointer<WorkflowContext> pContext) override;
+		void onWorkflowStarted(const QSharedPointer<WorkflowRequest>& pRequest) override;
+		void onWorkflowFinished(const QSharedPointer<WorkflowRequest>& pRequest) override;
 		void onUiDomination(const UIPlugIn* pUi, const QString& pInformation, bool pAccepted) override;
 		void onUiDominationReleased() override;
 		void onNewWebSocketRequest(const QSharedPointer<HttpRequest>& pRequest);
