@@ -10,21 +10,20 @@
 
 #include "WorkflowController.h"
 #include "WorkflowRequest.h"
-#include "context/ActivationContext.h"
+#include "context/AuthContext.h"
 
 namespace governikus
 {
 
-class AuthContext;
-
 class AuthController
 	: public WorkflowController
 {
 	Q_OBJECT
 
 	public:
-		static QSharedPointer<WorkflowRequest> createWorkflowRequest(const QSharedPointer<ActivationContext>& pActivationContext);
-		static QSharedPointer<WorkflowRequest> createWorkflowRequest(const QUrl& pUrl);
+		static QSharedPointer<WorkflowRequest> createWorkflowRequest(const QUrl& pUrl,
+				const QVariant& pData = QVariant(),
+				const AuthContext::BrowserHandler& pBrowserHandler = AuthContext::BrowserHandler());
 
 		explicit AuthController(QSharedPointer<AuthContext> pContext);
 		~AuthController() override = default;
