@@ -4,14 +4,12 @@
 
 #include "controller/WorkflowController.h"
 
-#if defined(Q_OS_ANDROID) || defined(Q_OS_IOS)
-	#include "ReaderManager.h"
-#endif
+#include "states/AbstractState.h"
 
-#include <QDebug>
 
 using namespace governikus;
 
+
 WorkflowController::WorkflowController(const QSharedPointer<WorkflowContext>& pContext)
 	: mStateMachine()
 	, mContext(pContext)
@@ -20,6 +18,12 @@ WorkflowController::WorkflowController(const QSharedPointer<WorkflowContext>& pC
 }
 
 
+void WorkflowController::forceStartStopScan()
+{
+	mStateMachine.setProperty(AbstractState::cFORCE_START_STOP_SCAN, true);
+}
+
+
 void WorkflowController::run()
 {
 	mStateMachine.start();
