@@ -8,12 +8,14 @@
 
 #pragma once
 
+#include "context/WorkflowContext.h"
 #include "states/StateBuilder.h"
 
-#include <QScopedPointer>
 #include <QSharedPointer>
 #include <QStateMachine>
 
+class test_AppController;
+
 namespace governikus
 {
 
@@ -21,36 +23,38 @@ class WorkflowController
 	: public QObject
 {
 	Q_OBJECT
+	friend class ::test_AppController;
 
-	protected:
+	private:
 		QStateMachine mStateMachine;
 		const QSharedPointer<WorkflowContext> mContext;
 
-	public:
-		explicit WorkflowController(const QSharedPointer<WorkflowContext>& pContext);
-
-		void run();
-
-		[[nodiscard]] Action getAction() const
-		{
-			return mContext->getAction();
-		}
-
-
-		[[nodiscard]] QSharedPointer<WorkflowContext> getContext() const
-		{
-			return mContext;
-		}
-
-
+	protected:
 		template<typename T>
-		T* addState()
+		[[nodiscard]] T* addState()
 		{
 			auto state = StateBuilder::createState<T>(mContext);
 			mStateMachine.addState(state);
 			return state;
 		}
 
+
+		template<typename T>
+		[[nodiscard]] T* addInitialState()
+		{
+			auto state = addState<T>();
+			mStateMachine.setInitialState(state);
+			return state;
+		}
+
+
+		void forceStartStopScan();
+
+	public:
+		explicit WorkflowController(const QSharedPointer<WorkflowContext>& pContext);
+
+		void run();
+
 	Q_SIGNALS:
 		void fireComplete();
 
