@@ -19,10 +19,10 @@ class ElementDetector
 {
 	Q_DISABLE_COPY(ElementDetector)
 
-	protected:
+	private:
 		QXmlStreamReader mReader;
-		const QByteArray mXmlData;
 
+	protected:
 		void handleStartElements(const QStringList& pStartElementNames);
 		void detectStartElements(const QStringList& pStartElementNames);
 		virtual bool handleFoundElement(const QString& pElementName, const QString& pValue, const QXmlStreamAttributes& pAttributes) = 0;
