@@ -17,53 +17,11 @@ StatePreparePace::StatePreparePace(const QSharedPointer<WorkflowContext>& pConte
 }
 
 
-void StatePreparePace::run()
+void StatePreparePace::handleRetryCounter(int pRetryCounter)
 {
 	const auto& context = getContext();
-	context->setEstablishPaceChannelType(PacePasswordId::UNKNOWN);
-	const auto& cardConnection = context->getCardConnection();
-	if (!cardConnection)
-	{
-		qCDebug(statemachine) << "Card connection lost.";
-		Q_EMIT fireNoCardConnection();
-		return;
-	}
 
-	const int currentRetryCounter = cardConnection->getReaderInfo().getRetryCounter();
-	if (context->isSmartCardUsed())
-	{
-		if (currentRetryCounter == 0)
-		{
-			qCDebug(statemachine) << "Smart-eID was invalidated during workflow";
-			updateStatus(GlobalStatus::Code::Card_Smart_Invalid);
-			Q_EMIT fireAbort(FailureCode::Reason::Prepace_Pace_Smart_Eid_Invalidated);
-		}
-
-		qCDebug(statemachine) << "Smart-eID PIN required";
-		context->setEstablishPaceChannelType(PacePasswordId::PACE_PIN);
-		if (context->getPin().isEmpty())
-		{
-			Q_EMIT fireEnterPacePassword();
-			return;
-		}
-
-		Q_EMIT fireEstablishPaceChannel();
-		return;
-	}
-
-	if (context->isCanAllowedMode())
-	{
-		qCDebug(statemachine) << "CAN allowed required";
-		if (!requestPaceCanIfStillRequired())
-		{
-			Q_ASSERT(false && "This state must not be invoked any more if PACE_CAN was successful in CAN allowed mode.");
-			Q_EMIT fireContinue();
-		}
-		return;
-	}
-
-	Q_ASSERT(currentRetryCounter != -1);
-	switch (currentRetryCounter)
+	switch (pRetryCounter)
 	{
 		case 0:
 		{
@@ -95,7 +53,7 @@ void StatePreparePace::run()
 			qCDebug(statemachine) << "PIN allowed";
 			context->setEstablishPaceChannelType(PacePasswordId::PACE_PIN);
 
-			const bool pacePinDone = cardConnection->getPacePinSuccessful();
+			const bool pacePinDone = context->getCardConnection()->getPacePinSuccessful();
 			qCDebug(statemachine) << "PACE_PIN done:" << pacePinDone;
 			if (!pacePinDone)
 			{
@@ -109,11 +67,62 @@ void StatePreparePace::run()
 				return;
 			}
 
-			Q_UNREACHABLE();
+			Q_ASSERT(false && "This state must not be invoked any more if PACE_PIN already was successful.");
+			Q_EMIT fireContinue();
+			return;
 		}
 	}
+}
 
-	Q_UNREACHABLE();
+
+void StatePreparePace::run()
+{
+	const auto& context = getContext();
+	context->setEstablishPaceChannelType(PacePasswordId::UNKNOWN);
+	const auto& cardConnection = context->getCardConnection();
+	if (!cardConnection)
+	{
+		qCDebug(statemachine) << "Card connection lost.";
+		Q_EMIT fireNoCardConnection();
+		return;
+	}
+
+	const int currentRetryCounter = cardConnection->getReaderInfo().getRetryCounter();
+	if (context->isSmartCardUsed())
+	{
+		if (currentRetryCounter == 0)
+		{
+			qCDebug(statemachine) << "Smart-eID was invalidated during workflow";
+			updateStatus(GlobalStatus::Code::Card_Smart_Invalid);
+			Q_EMIT fireAbort(FailureCode::Reason::Prepace_Pace_Smart_Eid_Invalidated);
+			return;
+		}
+
+		qCDebug(statemachine) << "Smart-eID PIN required";
+		context->setEstablishPaceChannelType(PacePasswordId::PACE_PIN);
+		if (context->getPin().isEmpty())
+		{
+			Q_EMIT fireEnterPacePassword();
+			return;
+		}
+
+		Q_EMIT fireEstablishPaceChannel();
+		return;
+	}
+
+	if (context->isCanAllowedMode())
+	{
+		qCDebug(statemachine) << "CAN allowed required";
+		if (!requestPaceCanIfStillRequired())
+		{
+			Q_ASSERT(false && "This state must not be invoked any more if PACE_CAN was successful in CAN allowed mode.");
+			Q_EMIT fireContinue();
+		}
+		return;
+	}
+
+	Q_ASSERT(currentRetryCounter != -1);
+	handleRetryCounter(currentRetryCounter);
 }
 
 
