@@ -9,13 +9,9 @@
 #pragma once
 
 #include "AbstractState.h"
-#include "ECardApiResult.h"
 #include "GenericContextContainer.h"
 #include "context/AuthContext.h"
 
-#include <http_parser.h>
-
-
 class test_StateRedirectBrowser;
 
 
@@ -33,9 +29,6 @@ class StateRedirectBrowser
 	private:
 		explicit StateRedirectBrowser(const QSharedPointer<WorkflowContext>& pContext);
 
-		void reportCommunicationError();
-		void sendErrorPage(http_status pStatus);
-		bool sendRedirect(const QUrl& pRedirectAddress, const ECardApiResult& pResult);
 		void run() override;
 
 };
