@@ -26,11 +26,11 @@ StateSelectReader::StateSelectReader(const QSharedPointer<WorkflowContext>& pCon
 void StateSelectReader::run()
 {
 	const auto readerManager = Env::getSingleton<ReaderManager>();
-	mConnections += connect(readerManager, &ReaderManager::fireReaderAdded, this, &StateSelectReader::onReaderInfoChanged);
-	mConnections += connect(readerManager, &ReaderManager::fireReaderRemoved, this, &StateSelectReader::onReaderInfoChanged);
-	mConnections += connect(readerManager, &ReaderManager::fireCardInserted, this, &StateSelectReader::onReaderInfoChanged);
-	mConnections += connect(readerManager, &ReaderManager::fireCardRemoved, this, &StateSelectReader::onReaderInfoChanged);
-	mConnections += connect(readerManager, &ReaderManager::fireStatusChanged, this, &StateSelectReader::onReaderStatusChanged);
+	*this << connect(readerManager, &ReaderManager::fireReaderAdded, this, &StateSelectReader::onReaderInfoChanged);
+	*this << connect(readerManager, &ReaderManager::fireReaderRemoved, this, &StateSelectReader::onReaderInfoChanged);
+	*this << connect(readerManager, &ReaderManager::fireCardInserted, this, &StateSelectReader::onReaderInfoChanged);
+	*this << connect(readerManager, &ReaderManager::fireCardRemoved, this, &StateSelectReader::onReaderInfoChanged);
+	*this << connect(readerManager, &ReaderManager::fireStatusChanged, this, &StateSelectReader::onReaderStatusChanged);
 
 	onReaderInfoChanged();
 
@@ -103,7 +103,7 @@ void StateSelectReader::onReaderStatusChanged(const ReaderManagerPlugInInfo& pIn
 		return;
 	}
 
-	if (!Env::getSingleton<ReaderManager>()->isScanRunning(ReaderManagerPlugInType::NFC))
+	if (!pInfo.isScanRunning())
 	{
 		Q_EMIT getContext()->fireCancelWorkflow();
 	}
@@ -115,6 +115,8 @@ void StateSelectReader::onReaderStatusChanged(const ReaderManagerPlugInInfo& pIn
 
 void StateSelectReader::onEntry(QEvent* pEvent)
 {
+	AbstractState::onEntry(pEvent);
+
 	const WorkflowContext* const context = getContext().data();
 	Q_ASSERT(context);
 
@@ -122,7 +124,6 @@ void StateSelectReader::onEntry(QEvent* pEvent)
 	 * Note: the plugin types to be used in this state must be already set in the workflow context before this state is entered.
 	 * Changing the plugin types in the context, e.g. from {NFC} to {REMOTE}, causes the state to be left with a fireRetry signal.
 	 */
-	mConnections += connect(context, &WorkflowContext::fireReaderPlugInTypesChanged, this, &StateSelectReader::fireRetry);
+	*this << connect(context, &WorkflowContext::fireReaderPlugInTypesChanged, this, &StateSelectReader::fireRetry);
 
-	AbstractState::onEntry(pEvent);
 }
