@@ -11,6 +11,9 @@
 using namespace governikus;
 
 
+Q_DECLARE_LOGGING_CATEGORY(card_smart)
+
+
 StateCheckApplet::StateCheckApplet(const QSharedPointer<WorkflowContext>& pContext)
 	: AbstractState(pContext)
 	, GenericContextContainer<PersonalizationContext>(pContext)
@@ -20,7 +23,7 @@ StateCheckApplet::StateCheckApplet(const QSharedPointer<WorkflowContext>& pConte
 
 void StateCheckApplet::run()
 {
-	mConnections += Env::getSingleton<ReaderManager>()->callExecuteCommand([] {
+	*this << Env::getSingleton<ReaderManager>()->callExecuteCommand([] {
 			return QVariant::fromValue(SmartManager::get()->status());
 		}, this, &StateCheckApplet::onCommandDone);
 }
@@ -28,26 +31,31 @@ void StateCheckApplet::run()
 
 void StateCheckApplet::onCommandDone(const QVariant& pResult)
 {
+	Q_ASSERT(ReaderManager::isResultType<EidStatus>(pResult));
+
 	switch (pResult.value<EidStatus>())
 	{
 		case EidStatus::INTERNAL_ERROR:
 			updateStatus(GlobalStatus::Code::Workflow_Smart_eID_Applet_Preparation_Failed);
-			Q_EMIT fireAbort(FailureCode::Reason::Check_Applet_Error);
+			Q_EMIT fireAbort(FailureCode::Reason::Check_Applet_Internal_Error);
 			return;
 
-		case EidStatus::UNAVAILABLE:
-			updateStatus(GlobalStatus::Code::Workflow_Smart_eID_Unavailable);
-			Q_EMIT fireAbort(FailureCode::Reason::Check_Applet_Unavailable);
+		case EidStatus::NO_PROVISIONING:
+			Q_EMIT fireInstallApplet();
+			return;
+
+		case EidStatus::CERT_EXPIRED:
+		case EidStatus::PERSONALIZED:
+			Q_EMIT fireDeletePersonalization();
 			return;
 
 		case EidStatus::NO_PERSONALIZATION:
 			Q_EMIT fireContinue();
 			return;
 
-		case EidStatus::NO_PROVISIONING:
-		case EidStatus::APPLET_UNUSABLE:
-		case EidStatus::PERSONALIZED:
-			Q_EMIT fireFurtherStepRequired();
+		case EidStatus::UNUSABLE:
+			Q_EMIT fireDeleteApplet();
 			return;
+
 	}
 }
