@@ -12,9 +12,8 @@ using namespace governikus;
 StateSendTransmitResponsePersonalization::StateSendTransmitResponsePersonalization(const QSharedPointer<WorkflowContext>& pContext)
 	: StateGenericSendReceive(pContext,
 			PaosType::TRANSMIT,
-			{
-				PaosType::STARTPAOS_RESPONSE
-			}, true)
+			{},
+			true)
 {
 }
 
@@ -29,12 +28,3 @@ QSharedPointer<PaosCreator> StateSendTransmitResponsePersonalization::getAsCreat
 {
 	return getContext()->getTransmitResponse();
 }
-
-
-void StateSendTransmitResponsePersonalization::emitStateMachineSignal(PaosType pResponseType)
-{
-	if (pResponseType == PaosType::STARTPAOS_RESPONSE)
-	{
-		Q_EMIT fireReceivedStartPaosResponse();
-	}
-}
