@@ -10,8 +10,9 @@
 using namespace governikus;
 
 
-MockDataChannel::MockDataChannel()
-	: mId(QUuid::createUuid().toString())
+MockDataChannel::MockDataChannel(bool pPairing)
+	: mPairing(pPairing)
+	, mId(QUuid::createUuid().toString())
 	, mReceivedDataBlocks()
 {
 }
@@ -28,6 +29,12 @@ void MockDataChannel::close()
 }
 
 
+bool MockDataChannel::isPairingConnection() const
+{
+	return mPairing;
+}
+
+
 const QString& MockDataChannel::getId() const
 {
 	return mId;
